%% CRFB2_Stevens_fun.m
%
% Examine the concern that the ARLs are systematically biased because the
% exponent of the Stevens function for motion and texture differs from 1.
%
%  File: work/MLExper/CRFeedback2/analysis/CRFB2_Stevens_fun.m
%  Usage: publish('CRFB2_Stevens_fun.m','html') ;    % 'latex','doc','ppt'
%  Date: 2010-06-02

% 1.0.0 2010-06-02 AP: Wrote it

%% Get started
cd(fullfile(CRFeedback2_pathstr,'analysis')) ;
fprintf('\n\nCRFB2_Stevens_fun executed on %s.\n\n',datestr(now)) ;
fprintf('cd %s\n',pwd) ;

clear all ;

%% Load the data
H_filename = fullfile(CRFeedback2_pathstr,'data','H.mat') ;
D_filename = fullfile(CRFeedback2_pathstr,'data','D.mat') ;

%recalculatep = true ;
recalculatep = false ;
if (recalculatep || ~exist(H_filename,'file'))
    if (recalculatep || ~exist(D_filename,'file'))
        %- Write down repository revision number
        fprintf('!/usr/local/bin/svn info \n') ;
        !/usr/local/bin/svn info
        
        %- Concatenate the individual data files into one master ASCII file
        fprintf('!cat sbj*.dat > raw_data.dat \n') ;
        !cat sbj*.dat > raw_data.dat
        
        %- Import the ASCII data files to Matlab
        fprintf('\nD=CRFB2_import_data ...') ;
        g = fullfile(CRFeedback2_pathstr,'data','raw_data.dat') ;
        D = CRFB2_import_data(g,[],P) ;
        %- Save D for future use
        save(D_filename,'D') ;
        fprintf('\nsave %s \n',D_filename) ;
    else
        fprintf('load %s \n',D_filename) ;
        load(D_filename) ;
    end
    assert(exist('D','var')==1) ;
    
    %- Calculate the average response levels
    fprintf('\nH = CRFB2_data_by_sbj(D) ...\n') ;
    [H,P,ARL_params] = CRFB2_data_by_sbj(D,1,P) ;
    %- Save H for future use
    save(H_filename,'H') ;
    fprintf('\nsave %s \n\n',H_filename) ;
else
    fprintf('load %s \n\n',H_filename) ;
    load(H_filename) ;
end
assert(exist('H','var')==1) ;

N_trials = 350 ;   % per stimulus type
N_sbj = length(H) ;


%% Isolate the MOTION stimulus-response pairs

S_mot = zeros(N_trials,N_sbj) ;
R_mot = zeros(size(S_mot)) ;
for k=1:N_sbj
    S_mot(:,k) = H(k).MOTION_data(:,4) ;   % categ == fdbk
    R_mot(:,k) = H(k).MOTION_data(:,7) ;   % resp
end

xtab2(S_mot(:),R_mot(:))

%% Isolate the TEXTURE stimulus-response pairs

S_txt = zeros(N_trials,N_sbj) ;
R_txt = zeros(size(S_mot)) ;
for k=1:N_sbj
    S_txt(:,k) = H(k).TEXTURE_data(:,4) ;   % categ == fdbk
    R_txt(:,k) = H(k).TEXTURE_data(:,7) ;   % resp
end

xtab2(S_txt(:),R_txt(:))


%% Stevens functions
[s,S] = split(R_mot(:),S_mot(:)) ;
mR_mot = aggreg(s) ;

s = split(R_txt(:),S_txt(:)) ;
mR_txt = aggreg(s) ;

plot(S,mR_mot,'bo-',S,mR_txt,'rs-') ;
grid on
legend('MOTION','TEXTURE','location','NorthWest') ;
xlabel('Stimulus') ;  ylabel('Mean Response') ;

%% Correlations:

R070 = 1.6*S.^0.70 ;       % n=0.70 -- arbitrarily chosen, not fit to data
R140 = .7+(S.^1.4)./2.5 ;  % n=1.40 -- arbitrarily chosen, not fit to data

corrcoef([S mR_mot mR_txt R070 R140])

plot(S,mR_mot,'bo-',S,mR_txt,'rs-',S,R070,'k:',S,R140,'k--') ;
grid on
legend('MOTION','TEXTURE','n=0.70','n=1.40','location','NorthWest') ;
xlabel('Stimulus') ;  ylabel('Mean Response') ;

%% Clean up
clear k s

%% Conclusion:
%
% Even if the Stevens function is not linear, it is *locally* linear.
% The nonlinearity is negligible for the purposes of calculating the ARL.
% The correlation between the mean response (conditional on the stimuli)
% and the categories 1-7 is >.998 for both MOTION and TEXTURE.

% 2010-06-02
