%% CRFB2_empir_ARL_profile.m
%
% Final plot of the empirical Avg Response Levels w/ 56-trial blocks.
% See Figures 4 and 5 in ProtoPaper/expmt.tex.
% Compare with model_ARL2_predictions.m
%
%  File: work/MLExper/CRFeedback2/prog/CRFB2_empir_ARL_profile.m
%  Usage: publish('CRFB2_empir_ARL_profile.m','html') ;    % 'latex','doc','ppt'
%  Date: 2009-12-29

% 1.1.1 2009-12-29 AP: Export the ARL42 profiles to ASCII data files
% 1.1.0 2009-12-22 AP: Linestyles as in CMUExper/fdbk1/data/empir_ARL2_profile.m
% 1.0.0 2009-12-04 AP: Wrote it

%% Get started
cd(fullfile(CRFeedback2_pathstr,'data')) ;
fprintf('\n\nCRFB2_empir_ARL_profile executed on %s.\n\n',datestr(now)) ;
fprintf('cd %s\n',pwd) ;

clear all ;

%% Design parameters
% Load them from the code that administered the experiment:
P = CRFB2_params(0) ;
design_params = P.design_params ;

MOTION = P.enum.MOTION ;
TEXTURE = P.enum.TEXTURE ;

FAST_LOW = P.enum.FAST_LOW ;
SLOW_HIGH = P.enum.SLOW_HIGH ;
UNIF = P.enum.UNIF ;

idx1 = [1 2 3 6 7] ;  % feedback blocks42 for the feedback-first groups
idx2 = [1 4 5 8 9] ;  % feedback blocks42 for the no-feedback-first grps
  % @@@ See P.design_params.feedback_sched for the 28-trial blocks


x42 =     [ 7, 35:42:329] ;
xtick28 = (1.5:3:10.5) ;  % block-based, @@@@
xtick42 = (14:84:350) ;   % trial-based
xtick42b = (1.5:2:7.5) ;  % block-based

ytick_ARL = (3.0:.2:5.0) ;
axis28 = [0 14 3 5] ;     % block-based
axis42 = [0 350 3 5] ;    % trial-based
axis42b = [0 10 3 5] ;    % block-based

ytick_Assim = (-2.0:.5:0.5) ;
A_axis28 = [0 14 -2 0.5] ;  % block-based
A_axis42 = [0 350 -2 0.5] ; % trial-based
A_axis42b = [0 10 -2 0.5] ; % block-based



%% Load the data
H_filename = fullfile(CRFeedback2_pathstr,'data','H.mat') ;
D_filename = fullfile(CRFeedback2_pathstr,'data','D.mat') ;

%recalculatep = true ;
recalculatep = false ;
if (recalculatep || ~exist(H_filename,'file'))
    if (recalculatep || ~exist(D_filename,'file'))
        %- Write down repository revision number
        fprintf('!/usr/local/bin/svn info \n') ;
        !/usr/local/bin/svn info
        
        %- Concatenate the individual data files into one master ASCII file
        fprintf('!cat sbj*.dat > raw_data.dat \n') ;
        !cat sbj*.dat > raw_data.dat
        
        %- Import the ASCII data files to Matlab
        fprintf('\nD=CRFB2_import_data ...') ;
        g = fullfile(CRFeedback2_pathstr,'data','raw_data.dat') ;
        D = CRFB2_import_data(g,[],P) ;
        %- Save D for future use
        save(D_filename,'D') ;
        fprintf('\nsave %s \n',D_filename) ;
    else
        fprintf('load %s \n',D_filename) ;
        load(D_filename) ;
    end
    assert(exist('D','var')==1) ;
    
    %- Calculate the average response levels
    fprintf('\nH = CRFB2_data_by_sbj(D) ...\n') ;
    [H,P,ARL_params] = CRFB2_data_by_sbj(D,1,P) ;
    %- Save H for future use
    save(H_filename,'H') ;
    fprintf('\nsave %s \n\n',H_filename) ;
else
    fprintf('load %s \n\n',H_filename) ;
    load(H_filename) ;
end
assert(exist('H','var')==1) ;


%% Group descriptors
% group_descr = {'FastLow1' 'FastLow2' 'SlowHigh1' 'SlowHigh2'} ;
group_descr = design_params.group_descr     %#ok<NOPTS>
N_groups = length(group_descr) ;            % 4
FastLow1 = 1 ;     % group identifiers
FastLow2 = 2 ;
SlowHigh1 = 3 ;
SlowHigh2 = 4 ;
%fdbk_first_p = [1 0 1 0] ;    % exp schedule by group

sbj = [H.sbj]' ;
gr = [H.group]' ;
xtab1(gr)

N_sbj = length(H) ;

%% Collect the ARLs for each group
N_blocks28 = length(H(1).schedule28) ;
N_blocks42 = length(H(1).schedule42) ;

sbj_gr = cell(1,N_groups) ;
MTN_ARL28 = cell(1,N_groups) ;
MTN_ARL42 = cell(1,N_groups) ;
TXT_ARL28 = cell(1,N_groups) ;
TXT_ARL42 = cell(1,N_groups) ;

grMTN_ARL28 = NaN(N_blocks28,N_groups) ;
grMTN_ARL42 = NaN(N_blocks42,N_groups) ;
grTXT_ARL28 = NaN(N_blocks28,N_groups) ;
grTXT_ARL42 = NaN(N_blocks42,N_groups) ;
N_sbj_per_gr = NaN(1,N_groups) ;

for g = 1:N_groups
    idx = find(gr==g) ;
    
    % Demographics
    N_sbj_per_gr(g) = length(idx) ;
    sbj_gr{g} = [sbj(idx), gr(idx)] ;    % <subject, group>
    
    % MOTION
    MTN_ARL28{g} = [H(idx).MOTION_ARL28] ;
    grMTN_ARL28(:,g) = mean(MTN_ARL28{g},2) ;
    MTN_ARL42{g} = [H(idx).MOTION_ARL42] ;
    grMTN_ARL42(:,g) = mean(MTN_ARL42{g},2) ;
    
    % TEXTURE
    TXT_ARL28{g} = [H(idx).TEXTURE_ARL28] ;
    grTXT_ARL28(:,g) = mean(TXT_ARL28{g},2) ;
    TXT_ARL42{g} = [H(idx).TEXTURE_ARL42] ;
    grTXT_ARL42(:,g) = mean(TXT_ARL42{g},2) ;
end

%% Plot the 28-trial ARL profiles
% @@@ using default line colors for the time being
subplot(1,2,1) ;
plot(grMTN_ARL28,'o-') ; 
axis(axis28) ; set(gca,'xtick',xtick28,'ytick',ytick_ARL) ; grid on ;
legend(group_descr,'location','SouthEast') ;
xlabel('Block (28 trials each)') ; ylabel('Mean ARL') ;
title(sprintf('MOTION ARL28, %d Ss, 2009-12-04',N_sbj)) ;

subplot(1,2,2) ;
plot(grTXT_ARL28,'o-') ; 
axis(axis28) ; set(gca,'xtick',xtick28,'ytick',ytick_ARL) ; grid on ;
legend(group_descr,'location','NorthEast') ;
xlabel('Block (28 trials each)') ; ylabel('Mean ARL') ;
title(sprintf('TEXTURE ARL28, %d Ss, 2009-12-04',N_sbj)) ;

%% Plot the 42-trial ARL profiles
% @@@ using default line colors for the time being
subplot(1,2,1) ;
plot(grMTN_ARL42,'o-') ; 
axis(axis42b) ; set(gca,'xtick',xtick42b,'ytick',ytick_ARL) ; grid on ;
legend(group_descr,'location','SouthEast') ;
xlabel('Block (42 trials each)') ; ylabel('Mean ARL') ;
title(sprintf('MOTION ARL42, %d Ss, 2009-12-04',N_sbj)) ;

subplot(1,2,2) ;
plot(grTXT_ARL42,'o-') ; 
axis(axis42b) ; set(gca,'xtick',xtick42b,'ytick',ytick_ARL) ; grid on ;
legend(group_descr,'location','NorthEast') ;
xlabel('Block (42 trials each)') ; ylabel('Mean ARL') ;
title(sprintf('TEXTURE ARL42, %d Ss, 2009-12-04',N_sbj)) ;


%% Production-quality plot of Motion ARL42
% Same LineStyles as CMUExper/fdbk1/data/empir_ARL2_profile.m
ls =      {'b-'      'k<-'    'b--'     'k<--'} ; % group line styles
lw =      [2         2        2         2] ;      % group line widths
MTN_leg = {'Slow1'   'Fast1'  'Slow2'   'Fast2'} ;
MTN_gr4 = [SlowHigh1 FastLow1 SlowHigh2 FastLow2] ;
for k = 1:4    % Add group number in the legend
    MTN_leg{k} = sprintf('Group %d: %s',MTN_gr4(k),MTN_leg{k}) ;
end
disp([group_descr(MTN_gr4) ; MTN_leg]) ;  % should match

clf ; hold on ;
for k = 1:4
    g = MTN_gr4(k) ;
    hh = plot(x42,grMTN_ARL42(:,g),ls{k}) ;
    set(hh,'LineWidth',lw(k),'MarkerSize',4) ;
end
hold off ; box on ;
axis(axis42) ; set(gca,'xtick',xtick42,'ytick',ytick_ARL,'xgrid','on') ;
hh = xlabel('Motion Trial') ; set(hh,'FontSize',14) ;
hh = ylabel('Average response level') ; set(hh,'FontSize',14) ;
hh = legend(MTN_leg,'location','SouthEast') ; set(hh,'FontSize',14) ;
%hh = legend(group_descr(MTN_gr4),'location','SouthEast') ; set(hh,'FontSize',14) ;
% Saved as work/papers/ProtoPaper/fig/ARL-motion.eps, 2009-12-28
% Preview.app converted it to ARL-motion.pdf


%% Production-quality plot of Texture ARL42
% Same LineStyles as CMUExper/fdbk1/data/empir_ARL2_profile.m
%ls =     {'b-'      'k<-'    'b--'     'k<--'} ; % group line styles
%lw =     [2         2        2         2] ;      % group line widths
TXT_leg = {'Low1'    'High1'  'Low2'   'High2'} ;
TXT_gr4 = [FastLow1 SlowHigh1 FastLow2 SlowHigh2] ;
for k = 1:4    % Add group number in the legend
    TXT_leg{k} = sprintf('Group %d: %s',TXT_gr4(k),TXT_leg{k}) ;
end
disp([group_descr(TXT_gr4) ; TXT_leg]) ;  % should match

clf ; hold on ;
for k = 1:4
    g = TXT_gr4(k) ;
    hh = plot(x42,grTXT_ARL42(:,g),ls{k}) ;
    set(hh,'LineWidth',lw(k),'MarkerSize',4) ;
end
hold off ; box on ;
axis(axis42) ; set(gca,'xtick',xtick42,'ytick',ytick_ARL,'xgrid','on') ;
hh = xlabel('Texture Trial') ; set(hh,'FontSize',14) ;
hh = ylabel('Average response level') ; set(hh,'FontSize',14) ;
hh = legend(TXT_leg,'location','NorthEast') ; set(hh,'FontSize',14) ;
%hh = legend(group_descr(TXT_gr4),'location','NorthEast') ; set(hh,'FontSize',14) ;
% Saved as work/papers/ProtoPaper/fig/ARL-texture.eps, 2009-12-28
% Preview.app converted it to ARL-texture.pdf



%% Define Assimilation
Assim_legend = {'Fdbk 1st','No-fdbk 1st'} ;

grMTN_Assim28 = grMTN_ARL28(:,[FastLow1  FastLow2]) - ...   % Fast
                grMTN_ARL28(:,[SlowHigh1 SlowHigh2]) ;      % Slow

grMTN_Assim42 = grMTN_ARL42(:,[FastLow1  FastLow2]) - ...   % Fast
                grMTN_ARL42(:,[SlowHigh1 SlowHigh2]) ;      % Slow

MTN_A_leg = {sprintf('Gr%d - Gr%d: Feedback first',FastLow1,SlowHigh1) ...
             sprintf('Gr%d - Gr%d: No-feedback first',FastLow2,SlowHigh2)} ;
            

grTXT_Assim28 = grTXT_ARL28(:,[SlowHigh1 SlowHigh2]) - ...  % High
                grTXT_ARL28(:,[FastLow1  FastLow2]) ;       % Low

grTXT_Assim42 = grTXT_ARL42(:,[SlowHigh1 SlowHigh2]) - ...  % High
                grTXT_ARL42(:,[FastLow1  FastLow2]) ;       % Low

TXT_A_leg = {sprintf('Gr%d - Gr%d: Feedback first',SlowHigh1,FastLow1) ...
             sprintf('Gr%d - Gr%d: No-feedback first',SlowHigh2,FastLow2)} ;


%% Plot the 28-trial Assimilation profiles
% @@@ using default line colors for the time being
subplot(1,2,1) ;
plot(grMTN_Assim28,'o-') ; 
axis(A_axis28) ; set(gca,'xtick',xtick28,'ytick',ytick_Assim) ; grid on ;
legend(Assim_legend,'location','SouthEast') ;
xlabel('Block (28 trials each)') ;
ylabel('Mean Assim=ARL(Fast)-ARL(Slow)') ;
title(sprintf('MOTION Assim28, %d Ss, 2009-12-04',N_sbj)) ;

subplot(1,2,2) ;
plot(grTXT_Assim28,'o-') ; 
axis(A_axis28) ; set(gca,'xtick',xtick28,'ytick',ytick_Assim) ; grid on ;
legend(Assim_legend,'location','SouthEast') ;
xlabel('Block (28 trials each)') ;
ylabel('Mean Assim=ARL(High)-ARL(Low)') ;
title(sprintf('TEXTURE Assim28, %d Ss, 2009-12-04',N_sbj)) ;

%% Plot the 42-trial Assimilation profiles
% @@@ using default line colors for the time being
subplot(1,2,1) ;
plot(grMTN_Assim42,'o-') ; 
axis(A_axis42b) ; set(gca,'xtick',xtick42b,'ytick',ytick_Assim) ; grid on ;
legend(Assim_legend,'location','SouthEast') ;
xlabel('Block (42 trials each)') ;
ylabel('Mean Assim=ARL(Fast)-ARL(Slow)') ;
title(sprintf('MOTION Assim42, %d Ss, 2009-12-04',N_sbj)) ;

subplot(1,2,2) ;
plot(grTXT_Assim42,'o-') ; 
axis(A_axis42b) ; set(gca,'xtick',xtick42b,'ytick',ytick_Assim) ; grid on ;
legend(Assim_legend,'location','SouthEast') ;
xlabel('Block (42 trials each)') ;
ylabel('Mean Assim=ARL(High)-ARL(Low)') ;
title(sprintf('TEXTURE Assim42, %d Ss, 2009-12-04',N_sbj)) ;


%% Production-quality plot of Motion Assim42
% Same LineStyles as CMUExper/fdbk1/data/empir_ARL2_profile.m
clf ;
hh = plot(x42,grMTN_Assim42(:,1),'r-' ...
         ,x42,grMTN_Assim42(:,2),'b--' ...
         ,x42(idx1),grMTN_Assim42(idx1,1),'ro' ...
         ,x42(idx2),grMTN_Assim42(idx2,2),'bs' ) ;
set(hh,'LineWidth',2) ;
axis(A_axis42) ;
hh=refline(0,0) ; set(hh,'Color','k','LineStyle','-','LineWidth',1) ;
box on ;
set(gca,'xtick',xtick42,'ytick',ytick_Assim,'xgrid','on') ;
hh = xlabel('Motion Trial') ; set(hh,'FontSize',14) ;
hh = ylabel('ARL(Fast) - ARL(Slow)') ; set(hh,'FontSize',14) ;
hh = legend(MTN_A_leg,'Location','SouthEast') ; set(hh,'FontSize',14) ;
% Saved as work/papers/ProtoPaper/fig/Assim-motion.eps, 2009-12-28
% Preview.app converted it to Assim-motion.pdf

%% Production-quality plot of Texture Assim42
% Same LineStyles as CMUExper/fdbk1/data/empir_ARL2_profile.m
clf ;
hh = plot(x42,grTXT_Assim42(:,1),'r-' ...
         ,x42,grTXT_Assim42(:,2),'b--' ...
         ,x42(idx1),grTXT_Assim42(idx1,1),'ro' ...
         ,x42(idx2),grTXT_Assim42(idx2,2),'bs' ) ;
set(hh,'LineWidth',2) ;
axis(A_axis42) ;
hh=refline(0,0) ; set(hh,'Color','k','LineStyle','-','LineWidth',1) ;
box on ;
set(gca,'xtick',xtick42,'ytick',ytick_Assim,'xgrid','on') ;
hh = xlabel('Texture Trial') ; set(hh,'FontSize',14) ;
hh = ylabel('ARL(High) - ARL(Low)') ; set(hh,'FontSize',14) ;
hh = legend(TXT_A_leg,'Location','SouthEast') ; set(hh,'FontSize',14) ;
% Saved as work/papers/ProtoPaper/fig/Assim-texture.eps, 2009-12-28
% Preview.app converted it to Assim-texture.pdf


%% Export MTN-ARL42 to SSPS for repeated-measures ANOVA
% Write an ASCII file with one row per subject and the following columns:
%
% * 1. Sbj -- Subject number (451-492, 999)
% * 2. Group -- 1=FastLow1, 2=FastLow2, 3=SlowHigh1, 4=SlowHigh2
% * 3. Task -- 1=MOTION throughout
% * 4. Context -- 1=Slow, 2=Fast
% * 5. Order -- 1=Feedback_first, 2=No_feedback_first
% * 6. W -- ARL2 value for the "warm-up" initial block
% * 7-10.  F1-F4 -- ARL42 values during the four feedback blocks
% * 11-14. N1-N4 -- ARL42 values during the four no-feedback blocks
%
% Note that this data format throws away the temporal order of
% observations.  They are rearranged depending on Order so that in the
% resulting ASCII file all feedback ARLs are listed in columns F1-F4 and
% all no-feedback ARLs are listed in columns N1-N4.
%
% Results of SPSS analyses available in work/MLExper/CRFeedback2/SPSS/

rearrange = [1, 2 3 6 7, 4 5 8 9 ; ...     % when order=1
             1, 4 5 8 9, 2 3 6 7 ]' ;      % when order=2
order_by_group = [1 2 1 2] ;        % FastLow1, FastLow2, SlowHigh1, SlowHigh2
MTN_context_by_group = [2 2 1 1] ;  % FastLow1, FastLow2, SlowHigh1, SlowHigh2

%- Prepare a matrix with the relevant data in the proper format
MTN_data42 = NaN(N_sbj,14) ;
for k = 1:N_sbj
    MTN_data42(k,1) = H(k).sbj ;
    g = H(k).group ;
    MTN_data42(k,2) = g ;
    MTN_data42(k,3) = MOTION ;                % = const
    MTN_data42(k,4) = MTN_context_by_group(g) ;
    MTN_data42(k,5) = order_by_group(g) ;
    idx = rearrange(:,order_by_group(g)) ;
    MTN_data42(k,6:14) = H(k).MOTION_ARL42(idx) ;
end

%- Sanity check
for g = 1:N_groups
    idx = find(MTN_data42(:,2)==g) ;
    hh = mean(MTN_data42(idx,6:14)) ;  %#ok<FNDSB> % rearranged mean_ARL for this group
    assert(all(grMTN_ARL42(rearrange(:,order_by_group(g)),g)==hh')) ;
end

% Write to an ASCII file
fid = fopen(fullfile(CRFeedback2_pathstr,'SPSS','MTN-ARL42-wn-Ss.dat'),'w') ;
hh = [fid 1] ;   % Echo on stdout using fprintN
fprintN(hh,'Sbj Group Task Context Order W F1 F2 F3 F4 N1 N2 N3 N4\n') ;
for k = 1:N_sbj
    fprintN(hh,...
      '%02d %1d %1d %1d %1d %5.3f %5.3f %5.3f %5.3f %5.3f %5.3f %5.3f %5.3f %5.3f\n',...
      MTN_data42(k,:)) ;
end
fclose(fid) ;


%% Export TXT-ARL42 to SSPS for repeated-measures ANOVA
% Write an ASCII file with one row per subject and the following columns:
%
% * 1. Sbj -- Subject number (451-492, 999)
% * 2. Group -- 1=FastLow1, 2=FastLow2, 3=SlowHigh1, 4=SlowHigh2
% * 3. Task -- 2=TEXTURE throughout
% * 4. Context -- 3=Low, 4=High
% * 5. Order -- 1=Feedback_first, 2=No_feedback_first
% * 6. W -- ARL2 value for the "warm-up" initial block
% * 7-10.  F1-F4 -- ARL42 values during the four feedback blocks
% * 11-14. N1-N4 -- ARL42 values during the four no-feedback blocks
%
% Note that this data format throws away the temporal order of
% observations.  They are rearranged depending on Order so that in the
% resulting ASCII file all feedback ARLs are listed in columns F1-F4 and
% all no-feedback ARLs are listed in columns N1-N4.
%
% Results of SPSS analyses available in work/MLExper/CRFeedback2/SPSS/

TXT_context_by_group = [3 3 4 4] ;  % FastLow1, FastLow2, SlowHigh1, SlowHigh2

%- Prepare a matrix with the relevant data in the proper format
TXT_data42 = NaN(N_sbj,14) ;
for k = 1:N_sbj
    TXT_data42(k,1) = H(k).sbj ;
    g = H(k).group ;
    TXT_data42(k,2) = g ;
    TXT_data42(k,3) = TEXTURE ;                % = const
    TXT_data42(k,4) = TXT_context_by_group(g) ;
    TXT_data42(k,5) = order_by_group(g) ;
    idx = rearrange(:,order_by_group(g)) ;
    TXT_data42(k,6:14) = H(k).TEXTURE_ARL42(idx) ;
end

%- Sanity check
for g = 1:N_groups
    idx = find(TXT_data42(:,2)==g) ;
    hh = mean(TXT_data42(idx,6:14)) ;  %#ok<FNDSB> % rearranged mean_ARL for this group
    assert(all(grTXT_ARL42(rearrange(:,order_by_group(g)),g)==hh')) ;
end

% Write to an ASCII file
fid = fopen(fullfile(CRFeedback2_pathstr,'SPSS','TXT-ARL42-wn-Ss.dat'),'w') ;
hh = [fid 1] ;   % Echo on stdout using fprintN
fprintN(hh,'Sbj Group Task Context Order W F1 F2 F3 F4 N1 N2 N3 N4\n') ;
for k = 1:N_sbj
    fprintN(hh,...
      '%02d %1d %1d %1d %1d %5.3f %5.3f %5.3f %5.3f %5.3f %5.3f %5.3f %5.3f %5.3f\n',...
      TXT_data42(k,:)) ;
end
fclose(fid) ;


%% Clean up
clear D hh k g idx fid ;

% 2009-12-28
